@@ -1,4 +1,4 @@
-/* $Id: mp4.c,v 1.8 2006/09/17 12:14:05 mbalmer Exp $ */
+/* $Id: mp4.c,v 1.9 2009/06/27 10:10:32 mbalmer Exp $ */
 
 /*
  * Copyright (c) 2006 Marcus Glocker <marcus@nazgul.ch>
@@ -84,7 +84,7 @@ mp4_seek_box(int fd, const char *type)
 		read(fd, buf, 4);
 
 		/* jump to next lower box level */
-		if (!strncmp(boxes[box], buf, 4)) {
+		if (!strncmp(boxes[box], (char *)buf, 4)) {
 			box++;
 			continue;
 		}
