@@ -1,4 +1,4 @@
-/* $Id: rtsp.c,v 1.8 2006/09/17 12:14:05 mbalmer Exp $ */
+/* $Id: rtsp.c,v 1.9 2009/06/27 10:10:32 mbalmer Exp $ */
 
 /*
  * Copyright (c) 2006 Marcus Glocker <marcus@nazgul.ch>
@@ -186,8 +186,9 @@ rtsp_Announce(void)
 	    sizeof(base64_rsaaeskey), 256);
 
 	/* remove base64 padding */
-	cipher_base64_rp(base64_aesiv, strlen(base64_aesiv));
-	cipher_base64_rp(base64_rsaaeskey, strlen(base64_rsaaeskey));
+	cipher_base64_rp((char *)base64_aesiv, strlen((char *)base64_aesiv));
+	cipher_base64_rp((char *)base64_rsaaeskey,
+	    strlen((char *)base64_rsaaeskey));
 
 	/* build body */
 	len_body = snprintf(body, sizeof(body),
@@ -209,7 +210,7 @@ rtsp_Announce(void)
 	    "Content-Type: application/sdp\r\n"
 	    "Content-Length: %ld\r\n"
 	    "\r\n",
-	    rtsp_execreq("ANNOUNCE"), len_body);
+	    rtsp_execreq("ANNOUNCE"), (long)len_body);
 
 	/* concatenate entity */
 	len = len_header + len_body + 1;
