@@ -1,7 +1,8 @@
-/* $Id: sys.c,v 1.5 2007/02/03 14:13:01 mbalmer Exp $ */
+/* $Id: sys.c,v 1.7 2008/02/10 11:41:10 mbalmer Exp $ */
 
 /*
- * Copyright (c) 2006 Marcus Glocker <marcus@nazgul.ch>
+ * Copyright (c) 2008 Marc Balmer <mbalmer@openbsd.org>
+ * Copyright (c) 2006-2008 Marcus Glocker <marcus@nazgul.ch>
  *
  * Permission to use, copy, modify, and distribute this software for any
  * purpose with or without fee is hereby granted, provided that the above
@@ -26,9 +27,13 @@
 #include <err.h>
 #include <errno.h>
 #include <netdb.h>
+#include <stdio.h>
+#include <stdlib.h>
 #include <string.h>
 #include <unistd.h>
 
+extern int ai_family;
+
 /*
  * sys_connect()
  *	connect a host
@@ -38,27 +43,52 @@
 int
 sys_connect(const char *hostname, int port)
 {
-	int			 sfd;
-	struct hostent		*he;
-	struct sockaddr_in	 address;
+	struct addrinfo hints, *res, *res0;
+	int s;
+	char hbuf[NI_MAXHOST], sbuf[NI_MAXSERV];
+	char buf[1024];
+	int error;
 
-	if ((he = gethostbyname(hostname)) == NULL)
-		return (-1);
+	/* resolve address/port into sockaddr */
+	memset(&hints, 0, sizeof(hints));
+	hints.ai_socktype = SOCK_STREAM;
+	hints.ai_family = ai_family;
+	snprintf(buf, sizeof(buf), "%d", port);
+	error = getaddrinfo(hostname, buf, &hints, &res0);
+	if (error) {
+		fprintf(stderr, "%s: %s\n", hostname,
+		    gai_strerror(error));
+		exit(1);
+		/*NOTREACHED*/
+	}
 
-	if ((sfd = socket(AF_INET, SOCK_STREAM, 0)) == -1)
-		return (-1);
+	/* try all the sockaddrs until connection goes successful */
+	for (res = res0; res; res = res->ai_next) {
+		error = getnameinfo(res->ai_addr, res->ai_addrlen, hbuf,
+		    sizeof(hbuf), sbuf, sizeof(sbuf),
+		    NI_NUMERICHOST | NI_NUMERICSERV);
+		if (error) {
+			fprintf(stderr, "%s: %s\n", hostname,
+			    gai_strerror(error));
+			continue;
+		}
+		fprintf(stderr, "trying %s port %s\n", hbuf, sbuf);
 
-	address.sin_family = AF_INET;
-	address.sin_port = htons(port);
-	address.sin_addr = *((struct in_addr *)he->h_addr);
+		s = socket(res->ai_family, res->ai_socktype, res->ai_protocol);
+		if (s < 0)
+			continue;
 
-	memset(&(address.sin_zero), 0, sizeof(address.sin_zero));
+		if (connect(s, res->ai_addr, res->ai_addrlen) < 0) {
+			close(s);
+			s = -1;
+			continue;
+		}
+		return s;
+	}
 
-	if (connect(sfd, (struct sockaddr *)&address,
-	    (socklen_t)sizeof(struct sockaddr)) == -1)
-		return (-1);
-
-	return (sfd);
+	fprintf(stderr, "no destination to connect to\n");
+	exit(1);
+	/*NOTREACHED*/
 }
 
 /*
@@ -264,9 +294,8 @@ sys_strcuts(char *dst, const char *src, char start, char end,
 	if (start == '\0') {
 		dst[0] = src[0];
 		j++;
-		i++;
-	} else
-		i++;
+	}
+	i++;
 
         for (; src[i] != end && i < len && j != dsize - 1; i++, j++)
                 dst[j] = src[i];
